@@ -40,7 +40,7 @@
 #include <QStandardPaths>
 
 #include "searchbar_debug.h"
-#include <asyncselectorinterface.h>
+#include <interfaces/selectorinterface.h>
 #include <htmlextension.h>
 #include <textextension.h>
 #include <browserarguments.h>
@@ -48,6 +48,8 @@
 
 K_PLUGIN_CLASS_WITH_JSON(SearchBarPlugin, "searchbar.json")
 
+using namespace KonqInterfaces;
+
 SearchBarPlugin::SearchBarPlugin(QObject *parent,
                                  const QVariantList &) :
     KonqParts::Plugin(parent),
@@ -420,7 +422,7 @@ void SearchBarPlugin::updateComboVisibility()
     // NOTE: We hide the search combobox if the embedded kpart is ReadWrite
     // because web browsers by their very nature are ReadOnly kparts...
     m_searchComboAction->setVisible(!m_part->inherits("ReadWritePart") &&
-                                    !m_searchComboAction->associatedWidgets().isEmpty());
+                                    !m_searchComboAction->associatedObjects().isEmpty());
     m_openSearchDescs.clear();
 }
 
@@ -452,19 +454,19 @@ void SearchBarPlugin::HTMLDocLoaded()
     //NOTE: the link below seems to be dead
     // Testcase for this code: http://search.iwsearch.net
     HtmlExtension *ext = HtmlExtension::childObject(m_part);
-    AsyncSelectorInterface *selectorIface = qobject_cast<AsyncSelectorInterface*>(ext);
+    SelectorInterface *selectorIface = qobject_cast<SelectorInterface*>(ext);
     const QString query(QStringLiteral("head > link[rel=\"search\"][type=\"application/opensearchdescription+xml\"]"));
     if (selectorIface) {
-        auto callback = [this](const QList<AsyncSelectorInterface::Element>& elements) {
+        auto callback = [this](const QList<SelectorInterface::Element>& elements) {
             insertOpenSearchEntries(elements);
         };
-        selectorIface->querySelectorAllAsync(query, AsyncSelectorInterface::EntireContent, callback);
+        selectorIface->querySelectorAll(query, SelectorInterface::EntireContent, callback);
     }
 }
 
-void SearchBarPlugin::insertOpenSearchEntries(const QList<AsyncSelectorInterface::Element>& elements)
+void SearchBarPlugin::insertOpenSearchEntries(const QList<SelectorInterface::Element>& elements)
 {
-    for (const AsyncSelectorInterface::Element &link : elements) {
+    for (const SelectorInterface::Element &link : elements) {
         const QString title = link.attribute(QStringLiteral("title"));
         const QString href = link.attribute(QStringLiteral("href"));
         //qCDebug(SEARCHBAR_LOG) << "Found opensearch" << title << href;
@@ -596,7 +598,6 @@ bool SearchBarCombo::overIcon(int x)
     const int x0 = QStyle::visualRect(layoutDirection(), style()->subControlRect(QStyle::CC_ComboBox, &opt, QStyle::SC_ComboBoxEditField, this), rect()).x();
     return (x > x0 + 2 && x < lineEdit()->x());
 }
-
 void SearchBarCombo::contextMenuEvent(QContextMenuEvent *e)
 {
     if (overIcon(e->x())) {
@@ -612,7 +613,7 @@ void SearchBarCombo::contextMenuEvent(QContextMenuEvent *e)
 
 void SearchBarCombo::mousePressEvent(QMouseEvent *e)
 {
-    if (overIcon(e->x())) {
+    if (overIcon(e->position().toPoint().x())) {
         emit iconClicked();
         e->accept();
     } else {
