@@ -1,3 +1,3 @@
 #! /usr/bin/env bash
 $EXTRACTRC `find . -name \*.ui` >> rc.cpp
-$XGETTEXT *.cpp css/*.cpp -o $podir/kcmkonqhtml.pot
+$XGETTEXT `find . -name '*.cpp'` -o $podir/kcmkonqhtml.pot
