@@ -39,10 +39,6 @@ public:
      */
     ~TabsOptions();
 
-#if QT_VERSION_MAJOR < 6
-    void setNeedsSave(bool needs) {emit changed(needs);}
-#endif
-
 public slots:
 
     /**
