@@ -16,6 +16,8 @@ namespace KonqInterfaces
     class CookieJar;
 }
 
+class KonquerorApplication;
+
 /**
  * @brief Implementation of KonqInterfaces::Browser
  */
@@ -60,6 +62,12 @@ public:
      */
     bool canNavigateTo(KParts::ReadOnlyPart *part, const QUrl &url) const override;
 
+    /**
+     * @brief Implementation of KonqInterfaces::Browser::openUrl()
+     * @see KonqInterfaces::Browser::openUrl()
+     */
+    bool openUrl(const QUrl & url, KParts::OpenUrlArguments & args, const BrowserArguments & bargs, QWidget * window = nullptr) override;
+
 private:
 
     /**
@@ -84,6 +92,11 @@ private:
      */
     void readDefaultUserAgent();
 
+    /**
+     * @brief Helper function returning `qApp` cast to a KonquerorApplication
+     */
+    KonquerorApplication* app() const;
+
     UserAgentData m_userAgent; ///< The user agent data
 
     QPointer<KonqInterfaces::CookieJar> m_cookieJar; ///< Holds the cookie jar
