@@ -74,6 +74,10 @@ class ReadOnlyPart;
 class OpenUrlArguments;
 }
 
+namespace Konq {
+    class ViewType;
+}
+
 class KonqExtendedBookmarkOwner;
 
 class KONQ_TESTS_EXPORT KonqMainWindow : public KParts::MainWindow, public KonqFrameContainerBase
@@ -92,6 +96,8 @@ public:
     explicit KonqMainWindow(const QUrl &initialURL = QUrl());
     ~KonqMainWindow() override;
 
+    static KonqMainWindow* mostSuitableWindow();
+
     /**
      * Filters the URL and calls the main openUrl method.
      */
@@ -125,14 +131,13 @@ public Q_SLOTS:
 
 public:
     /**
-     * Called by openUrl when it knows the mime type (either directly,
-     * or using KonqRun).
-     * \param mimeType the mimetype of the URL to open. Always set.
+     * Called by openUrl when it knows the mime type
+     * \param type the type of the URL to open. Always set.
      * \param url the URL to open.
      * \param childView the view in which to open the URL. Can be 0, in which
      * case a new tab (or the very first view) will be created.
      */
-    bool openView(QString mimeType, const QUrl &url, KonqView *childView,
+    bool openView(Konq::ViewType type, const QUrl &url, KonqView *childView,
                   const KonqOpenURLRequest &req = KonqOpenURLRequest::null, QUrl requestedUrl={});
 
 //     bool openView(const QString &mimetype, const QUrl &url, KService::Ptr service);
@@ -414,7 +419,7 @@ public Q_SLOTS:
     void slotViewModeTriggered(QAction *action);
     void slotLockView();
     void slotLinkView();
-    void slotReload(KonqView *view = nullptr, bool softReload = true);
+    void slotReload(KonqView *view = nullptr);
     void slotForceReload();
     void slotStop();
 
@@ -565,8 +570,8 @@ protected:
 
     bool makeViewsFollow(const QUrl &url,
                          const KParts::OpenUrlArguments &args,
-                         const BrowserArguments &browserArgs, const QString &serviceType,
-                         KonqView *senderView);
+                         const BrowserArguments &browserArgs,
+                         const Konq::ViewType &type, KonqView *senderView);
 
     void applyKonqMainWindowSettings();
 
