@@ -10,7 +10,7 @@
 #define URLLLOADER_H
 
 #include "konqopenurlrequest.h"
-#include "browseropenorsavequestion.h"
+#include "downloadactionquestion.h"
 
 #include <QObject>
 #include <QUrl>
@@ -30,8 +30,7 @@ namespace KIO {
     class MimeTypeFinderJob;
 }
 namespace KonqInterfaces {
-    class DownloaderExtension;
-    class DownloaderJob;
+    class DownloadJob;
 }
 class KonqMainWindow;
 class KonqView;
@@ -54,14 +53,12 @@ class KonqView;
  * and perform the action itself.
  *
  * @internal
- * For remote files, what happens after goOn depends on whether the metadata associated with the request to open the
- * URL (`m_request.args.metaData()`) contains the key DownloaderInterface::requestDownloadByPartKey():
- * - if the key doesn't exist, this class will determine the mimetype of the URL (if needed), then embed, open or save it
+ * For remote files, what happens after goOn depends on whether the BrowserArguments associated with the request
+ * provides a DownloadJob:
+ * - if it doesn't, this class will determine the mimetype of the URL (if needed), then embed, open or save it
  *   depending on the mimetype and the user's previous choices
- * - if the key exists, (after determining the mimetype of the URL, if not already known), this class will check whether
- *   the requesting part implements the DownloaderInterface. If so, it'll let the job returned by DownloaderInterface::downloadJob()
- *   to download the URL, then it will update #m_url so that it contains the path of the downloaded file. It then proceeds as
- *   in the above case. If the file should be saved, it'll simply moved from the download location to the location chosen by the user
+ * - if it does, the job will be used to download the URL, then #m_url will be updated so that it contains the path
+ *   of the downloaded file, then it proceeds as above
  */
 class UrlLoader : public QObject
 {
@@ -82,15 +79,7 @@ public:
     ~UrlLoader();
 
 
-    /** @brief Enum describing the possible actions to be taken*/
-    enum class OpenUrlAction{
-        UnknwonAction, /**< The action hasn't been decided yet */
-        DoNothing, /**< No action should be taken */
-        Save, /**< Save the URL */
-        Embed, /**< Display the URL in an embedded viewer */
-        Open, /**< Display the URL in a separate viewer*/
-        Execute /**< Execute the URL */
-    };
+    using OpenUrlAction = Konq::UrlAction;
 
     /** @brief Enum describing the view to use to embed an URL*/
     enum class ViewToUse{
@@ -144,7 +133,6 @@ public:
     void setView(KonqView *view);
     bool isAsync() const {return m_isAsync;}
     void setOldLocationBarUrl(const QString &old);
-    // QString oldLocationBarUrl() const {return m_oldLocationBarUrl;}
     bool hasError() const {return m_jobErrorCode;}
     void setNewTab(bool newTab);
 
@@ -171,29 +159,18 @@ private slots:
     /**
      * @brief Slot called when a part which has asked to download itself the URL has finished doing so
      *
-     * @param job the DownloaderJob used by the part to download the URL
+     * @param job the DownloadJob used by the part to download the URL
      */
-    void downloadForEmbeddingOrOpeningDone(KonqInterfaces::DownloaderJob *job, const QUrl &url);
+    void downloadForEmbeddingOrOpeningDone(KonqInterfaces::DownloadJob *job, const QUrl &url);
 
 private:
 
     /**
-     * @brief Sets the list of allowed options depending on the arguments passed to the constructor
+     * @brief Remove actions which won't be available depending on the mimetype and URL
      *
-     * Currently, the algorithm works as follows:
-     * - if @p req has the \link KonqOpenURLRequest::forceAutoEmbed forceAutoEmbed\endlink flag set to `true`
-     *  then the only allowed action is Embed
-     * - if the \link KonqOpenURLRequest::args args\endlink field in @p req has a `action` meta data entry, then
-     *  only that action will be allowed
-     *
-     * @param req the object containing the request
-     * @param dontEmbed whether embedding should be forbidden
-     * @note This function changes the value of #m_allowedActions
-     *
-     * @note If the \link KonqOpenURLRequest::forceAutoEmbed forceAutoEmbed\endlink flag of @p req is `true` and
-     *  an action is specified in the metadata, the flag will have precedence
+     * This removes the
      */
-    void initAllowedActions(const KonqOpenURLRequest &req);
+    void updateAllowedActions();
 
     void embed();
     void open();
@@ -211,9 +188,7 @@ private:
     void killOpenUrlJob();
     static bool serviceIsKonqueror(KService::Ptr service);
     static bool isMimeTypeKnown(const QString &mimeType);
-    bool decideEmbedOrSave();
-    void decideOpenOrSave();
-    bool embedWithoutAskingToSave(const QString &mimeType);
+    void decideEmbedOpenOrSave();
     bool shouldUseDefaultHttpMimeype() const;
     void decideAction();
     bool isViewLocked() const;
@@ -281,25 +256,10 @@ private:
     void determineStartingMimetype();
 
     /**
-     * @brief Casts the requesting part or one of its children to a DownloaderInterface*, if possible
-     * @note Since this uses DownloaderInterface::interface(), it's slower than a simple cast
-     * @return the requesting part or one of its children casted to a DownloaderInterface* or `nullptr` if
-     * the requesting part is `nullptr` or neither it nor its children implement DownloaderInterface
-     */
-    KonqInterfaces::DownloaderExtension* downloaderInterface() const;
-
-    /**
-     * @brief Retrieves from the requesting part a DownloaderJob to download the URL
+     * @brief Downloads the URL using the job provided by #m_request, if any
      *
-     * The retrieved job is stored in #m_partDownloaderJob. If downloaderInterface()
-     * returns `nullptr`, #m_partDownloaderJob is set to `nullptr`
-     */
-    void getDownloaderJobFromPart();
-
-    /**
-     * @brief Downloads the URL using the job provided by the requesting part, if any
-     *
-     * If #m_partDownloaderJob is `nullptr`, nothing is done
+     * If \link BrowserArguments::downloadJob m_request.browserArguments.downloadJob\endlink is `nullptr`,
+     * nothing is done
      */
     void downloadForEmbeddingOrOpening();
 
@@ -324,44 +284,13 @@ private:
 
     enum class OpenEmbedMode{Open, Embed};
 
-    /**
-     * @brief Asks the user whether he wants to save the url or open/embed it
-     *
-     * This will display the user a `KParts::BrowserOpenOrSaveQuestion` dialog, in open or embed mode depending on the argument.
-     * When displaying the dialog in "open" mode, it also allows to choose the application to use.
-     *
-     * @param mode tells the kind of dialog to show the user: and "Embed or save" dialog if this is OpenEmbedMode::Embed or an "Open
-     * or save" dialog if it is OpenEmbedMode::Open
-     * @return an object describing the user's choices. The first element is the action the user has chosen and can only be OpenUrlAction::Save,
-     * OpenUrlAction::Open, OpenUrlAction::Embed, OpenUrlAction::DoNothing. The second element is the service chosen by the user if @p mode is
-     * OpenEmbedMode::Open and `nullptr` otherwise.
-     * @note If @p mode is OpenEmbedMode::Open and the second element of the returned value is `nullptr`, it may mean that the user has chosen the
-     * "Open with..." entry from the menu displayed by the "Open with..." button. The caller shouldn't try to decide itself which service to use; it
-     * should instead pass `nullptr` as argument to the KIO::ApplicationLauncherJob constructor, which will take care to display the "Open with..."
-     * dialog to the user.
-     */
-    OpenSaveAnswer askSaveOrOpen(OpenEmbedMode mode) const;
-    OpenUrlAction decideExecute() const;
+    void askEmbedSaveOrOpen();
 
-    /**
-     * @brief Attempts to change the action
-     *
-     * If the given action is not allowed, it set the action to #DoNothing, instead
-     * @param action the new value of the action
-     * @return `true` if the action was set correctly and `false` if @p action wasn't
-     * allowed and the action was set to #DoNothing
-     */
-    bool setAction(OpenUrlAction action);
+    void decideExecute();
 
-    /**
-     * @brief Whether we are forced to perform the given action
-     *
-     * Being forced to perform an action means that it's the only action in #m_allowedActions
-     * @param action the action to check
-     * @return `true` if @p action is the only entry in #m_allowedActions and `false` otherwise
-     * @note this function also returns `false` if #m_allowedActions doesn't contain @p action
-     */
-    bool isForced(OpenUrlAction action) const;
+    void findAvailableParts();
+
+    void findService();
 
     /**
      * @brief Whether we are allowed to perform the given action
@@ -387,21 +316,24 @@ private:
     KonqOpenURLRequest m_request;
     KonqView *m_view;
     bool m_trustedSource;
-    QList<OpenUrlAction> m_allowedActions = {OpenUrlAction::Open, OpenUrlAction::Embed, OpenUrlAction::Save, OpenUrlAction::Execute};
     bool m_ready = false;
     bool m_isAsync = false;
-    OpenUrlAction m_action = OpenUrlAction::UnknwonAction;
     KPluginMetaData m_part;
     KService::Ptr m_service;
     QPointer<KIO::OpenUrlJob> m_openUrlJob;
     QPointer<KIO::ApplicationLauncherJob> m_applicationLauncherJob;
     QPointer<KIO::MimeTypeFinderJob> m_mimeTypeFinderJob;
-    QPointer<KonqInterfaces::DownloaderJob> m_partDownloaderJob;
     QString m_oldLocationBarUrl;
     int m_jobErrorCode = 0;
-    bool m_dontPassToWebEnginePart;
+    bool m_ignoreDefaultHtmlPart;
     bool m_protocolAllowsReading;
-    bool m_letRequestingPartDownloadUrl = false; ///<Whether the URL should be downloaded by the part before opening/embedding/saving it
+    bool m_useDownloadJob = false; ///<Whether the URL should be downloaded by the part before opening/embedding/saving it
+    QPointer<KonqInterfaces::DownloadJob> m_downloadJob; //!<The job to use to download the URL, if any
+    /**
+     * @brief The allowed actions for the url
+     */
+    Konq::AllowedUrlActions m_allowedActions;
+
     /**
      * @brief Whether only the `embed` action is allowed
      *
@@ -427,6 +359,4 @@ private:
     QUrl m_originalUrl;
 };
 
-QDebug operator<<(QDebug dbg, UrlLoader::OpenUrlAction action);
-
 #endif // URLLLOADER_H
