@@ -14,12 +14,13 @@
 #include "webengineview.h"
 #include "settings/webenginesettings.h"
 #include "webenginepartdownloadmanager.h"
-#include "webenginewallet.h"
+#include "wallet/webenginewallet.h"
 #include <webenginepart_debug.h>
 #include "webenginepartcontrols.h"
 #include "navigationrecorder.h"
 #include "profile.h"
 #include "webenginepart_ext.h"
+#include "capturesourcechooserdlg.h"
 
 #include "libkonq_utils.h"
 #include "interfaces/browser.h"
@@ -30,6 +31,10 @@
 #include <KDialogJobUiDelegate>
 #include <QWebEngineView>
 
+#if QT_VERSION >= QT_VERSION_CHECK(6,7,0)
+#include <QWebEngineDesktopMediaRequest>
+#endif
+
 #include <KMessageBox>
 #include <KLocalizedString>
 #include <KShell>
@@ -69,6 +74,7 @@
 #include "htmlextension.h"
 
 using namespace KonqInterfaces;
+using namespace WebEngine;
 
 WebEnginePage::WebEnginePage(WebEnginePart *part, QWidget *parent)
     : QWebEnginePage(KonqWebEnginePart::Profile::defaultProfile(), parent),
@@ -82,12 +88,8 @@ WebEnginePage::WebEnginePage(WebEnginePart *part, QWidget *parent)
         WebEngineSettings::self()->computeFontSizes(view()->logicalDpiY());
     }
 
-    //setForwardUnsupportedContent(true);
-
     connect(this, &QWebEnginePage::geometryChangeRequested,
             this, &WebEnginePage::slotGeometryChangeRequested);
-    //    connect(this, SIGNAL(unsupportedContent(QNetworkReply*)),
-    //            this, SLOT(slotUnsupportedContent(QNetworkReply*)));
     connect(this, &QWebEnginePage::featurePermissionRequested,
             this, &WebEnginePage::slotFeaturePermissionRequested);
     connect(this, &QWebEnginePage::loadFinished,
@@ -97,6 +99,10 @@ WebEnginePage::WebEnginePage(WebEnginePart *part, QWidget *parent)
     connect(this, &QWebEnginePage::fullScreenRequested, this, &WebEnginePage::changeFullScreenMode);
     connect(this, &QWebEnginePage::recommendedStateChanged, this, &WebEnginePage::changeLifecycleState);
 
+#ifdef MEDIAREQUEST_SUPPORTED
+    connect(this, &QWebEnginePage::desktopMediaRequested, this, &WebEnginePage::chooseDesktopMedia);
+#endif
+
     connect(this, &QWebEnginePage::loadStarted, this, [this](){m_dropOperationTimer->stop();});
     m_dropOperationTimer->setSingleShot(true);
 
@@ -187,14 +193,11 @@ void WebEnginePage::requestDownload(QWebEngineDownloadRequest *item, bool newWin
         return;
     }
 
-    WebEngineDownloaderExtension *downloader = m_part->downloader();
-    Q_ASSERT(downloader);
-
-    downloader->addDownloadRequest(item);
-
+    WebEngineDownloadJob *job = new WebEngineDownloadJob(item, nullptr);
     BrowserArguments bArgs;
     bArgs.setForcesNewWindow(newWindow);
     bArgs.setSuggestedDownloadName(item->suggestedFileName());
+    bArgs.setDownloadJob(job);
     if (Konq::Settings::alwaysEmbedInNewTab()) {
         bArgs.setNewTab(true);
     }
@@ -207,75 +210,37 @@ void WebEnginePage::requestDownload(QWebEngineDownloadRequest *item, bool newWin
     }
     args.setMimeType(mime.name());
 
-    args.metaData().insert(QStringLiteral("DontSendToDefaultHTMLPart"), QString());
+    bArgs.setIgnoreDefaultHtmlPart(true);
 
-    if (objective == WebEnginePartDownloadManager::DownloadObjective::SaveOnly) {
-        args.metaData().insert("action", "save");
-        saveUrlToDiskAndDisplay(item, args, bArgs);
-        return;
-    } else if (objective == WebEnginePartDownloadManager::DownloadObjective::SaveAs) {
-        saveAs(item);
-    } else {
-        args.metaData().insert(QStringLiteral("TempFile"), QString());
-        emit downloader->downloadAndOpenUrl(url, item->id(), args, bArgs, true);
-        if (item->state() == QWebEngineDownloadRequest::DownloadRequested) {
-            qCDebug(WEBENGINEPART_LOG()) << "Automatically accepting download for" << item->url() << "This shouldn't happen";
-            item->accept();
-        }
-    }
-}
-
-void WebEnginePage::saveUrlToDiskAndDisplay(QWebEngineDownloadRequest* req, const KParts::OpenUrlArguments& args, const BrowserArguments& bArgs)
-{
-    QWidget *window = view() ? view()->window() : nullptr;
-
-    QString suggestedName = !req->suggestedFileName().isEmpty() ? req->suggestedFileName() : req->url().fileName();
-    QString downloadPath = Konq::askDownloadLocation(suggestedName, window);
-    if (downloadPath.isEmpty()) {
-        req->cancel();
-        return;
+    if (objective == WebEnginePartDownloadManager::DownloadObjective::SaveUrl || objective == WebEnginePartDownloadManager::DownloadObjective::SavePageAs) {
+        bArgs.setAllowedUrlActions(Konq::AllowedUrlActions{Konq::UrlAction::Save});
+    } else if (objective == WebEnginePartDownloadManager::DownloadObjective::AskUser) {
+        bArgs.setForceShowActionDialog(true);
     }
 
-    WebEngineDownloaderExtension *downloader = m_part->downloader();
-    DownloaderJob *job = downloader->downloadJob(req->url(), req->id(), this);
-    if (!job) {
-        return;
-    }
-
-    auto lambda = [this, args, bArgs](DownloaderJob *, const QUrl &url) {
-        emit m_part->browserExtension()->browserOpenUrlRequest(url, args, bArgs);
-    };
-    connect(job, &DownloaderJob::downloadResult, m_part, &WebEnginePart::displayActOnDownloadedFileBar);
-    job->startDownload(downloadPath, window, this, lambda);
-}
-
-void WebEnginePage::saveAs(QWebEngineDownloadRequest* req)
-{
-    QWidget *window = view() ? view()->window() : nullptr;
-
-    QString suggestedName = !req->suggestedFileName().isEmpty() ? req->suggestedFileName() : req->url().fileName();
-    QString downloadPath = Konq::askDownloadLocation(suggestedName, window);
-    if (downloadPath.isEmpty()) {
-        req->cancel();
-        return;
-    }
-
-    WebEngineDownloaderExtension *downloader = m_part->downloader();
-    DownloaderJob *job = downloader->downloadJob(req->url(), req->id(), this);
-    if (!job) {
-        return;
-    }
-
-    auto lambda = [this](DownloaderJob *dj, const QUrl &url) {
-        if (dj->error() == 0) {
-            m_part->openUrl(url);
-            return;
-        }
-        BrowserArguments bArgs;
+    if (objective == WebEnginePartDownloadManager::DownloadObjective::SavePageAs) {
         bArgs.setForcesNewWindow(true);
-        emit m_part->browserExtension()->browserOpenUrlRequest(url, {}, bArgs);
-    };
-    job->startDownload(downloadPath, window, this, lambda);
+        job->setCalledForSaveAs(true);
+        auto displayLocalFile = [this](KonqInterfaces::DownloadJob *job, const QUrl &url){
+            if (job->error()) {
+                return;
+            }
+            disconnect(job, &DownloadJob::downloadResult, m_part, &WebEnginePart::displayActOnDownloadedFileBar);
+            BrowserArguments newBargs;
+            newBargs.setAllowedUrlActions(Konq::AllowedUrlActions{Konq::UrlAction::Embed});
+            emit m_part->browserExtension()->browserOpenUrlRequest(url, {}, newBargs);
+        };
+        connect(job, &DownloadJob::downloadResult, m_part, displayLocalFile);
+    }
+
+    connect(job, &DownloadJob::downloadResult, m_part, &WebEnginePart::displayActOnDownloadedFileBar);
+    emit m_part->browserExtension()->browserOpenUrlRequestSync(url, args, bArgs, true);
+
+    if (item->state() == QWebEngineDownloadRequest::DownloadRequested) {
+        qCDebug(WEBENGINEPART_LOG()) << "Automatically accepting download for" << item->url() << "This shouldn't happen";
+        item->accept();
+    }
+
 }
 
 void WebEnginePage::setDropOperationStarted()
@@ -823,6 +788,23 @@ void WebEnginePage::updateUserStyleSheet(const QString& script)
     runJavaScript(script, QWebEngineScript::ApplicationWorld);
 }
 
+#ifdef MEDIAREQUEST_SUPPORTED
+void WebEnginePage::chooseDesktopMedia(const QWebEngineDesktopMediaRequest& request)
+{
+    CaptureSourceChooserDlg chooser(url(), request.windowsModel(), request.screensModel(), view());
+    chooser.exec();
+    QModelIndex chosenIndex = chooser.choice();
+    if (chosenIndex.model() == request.windowsModel()) {
+        request.selectWindow(chosenIndex);
+    } else if (chosenIndex.model() == request.screensModel()) {
+        request.selectScreen(chosenIndex);
+    } else {
+        request.cancel();
+        return;
+    }
+}
+#endif
+
 /************************************* Begin NewWindowPage ******************************************/
 
 NewWindowPage::NewWindowPage(WebWindowType type, WebEnginePart* part, QWidget* parent)
@@ -909,11 +891,6 @@ bool NewWindowPage::acceptNavigationRequest(const QUrl &url, NavigationType type
     emit part()->browserExtension()->browserCreateNewWindow(url, uargs, bargs, wargs, &newWindowPart);
     qCDebug(WEBENGINEPART_LOG) << "Created new window" << newWindowPart;
 
-    if (newWindowPart && newWindowPart->widget()->topLevelWidget() != part()->widget()->topLevelWidget()) {
-        KParts::OpenUrlArguments args;
-        args.metaData().insert(QL1S("new-window"), QL1S("true"));
-        newWindowPart->setArguments(args);
-    }
     deleteLater();
     return false;
 }
